/**
 * Copyright 2016 the WHATAP project authors. All rights reserved.
 * Use of this source code is governed by a license that
 * can be found in the LICENSE file.
 */

require('./seedrandom');

var Long    = require('long'),
    rand    = new Math.seedrandom(Date.now(), {entropy : true});

var KeyGen = {
    next : function () {
        return parseInt((Long.fromBits(rand.int32(), rand.int32())).toString());
    },
    getMtid : function () {
        return Long.fromBits(rand.int32(), rand.int32());
    }
};

module.exports = KeyGen;